<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Vogue
 */

function customizer_library_vogue_options() {
	
    $site_boxed_color = '#FFFFFF';
	$primary_color = '#F061A8';
	$secondary_color = '#EA1B82';
    
    $header_bg_color = '#FFFFFF';
    $header_font_color = '#2D2D2D';
	
	$body_font_color = '#3C3C3C';
	$heading_font_color = '#000000';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;
    
	
    $panel = 'vogue-panel-layout';
    
    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Layout Options', 'vogue' ),
        'priority' => '30'
    );
    
    $section = 'vogue-site-layout-section';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Layout', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
	
    $choices = array(
        'vogue-site-boxed' => __( 'Boxed Layout', 'vogue' ),
        'vogue-site-full-width' => __( 'Full Width Layout', 'vogue' )
    );
    $options['vogue-site-layout'] = array(
        'id' => 'vogue-site-layout',
        'label'   => __( 'Site Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-site-full-width'
    );
    $options['vogue-set-container-width'] = array(
        'id' => 'vogue-set-container-width',
        'label'   => __( 'Site Container Width', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 900,
            'max'   => 1400,
            'step'  => 2,
        ),
        'description' => __( 'Set the width of your site between 900 pixels and 1400 pixels', 'vogue' ),
        'default' => 1240
    );
    $options['vogue-btt-button'] = array(
        'id' => 'vogue-btt-button',
        'label'   => __( 'Enable a Back To Top button', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    
    $section = 'vogue-page-layout-section';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Pages', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-page-remove-titlebar'] = array(
        'id' => 'vogue-page-remove-titlebar',
        'label'   => __( 'Remove Page Titles', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-titlebar-centered'] = array(
        'id' => 'vogue-titlebar-centered',
        'label'   => __( 'Center Align Page Titles', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    $choices = array(
        'vogue-page-fimage-layout-none' => __( 'None', 'vogue' ),
        'vogue-page-fimage-layout-standard' => __( 'Standard', 'vogue' ),
        'vogue-page-fimage-layout-banner' => __( 'Page Banner', 'vogue' )
    );
    $options['vogue-page-fimage-layout'] = array(
        'id' => 'vogue-page-fimage-layout',
        'label'   => __( 'Featured Image Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-page-fimage-layout-none'
    );
    $choices = array(
        'vogue-page-fimage-size-extra-small' => __( 'Extra Small Banner', 'vogue' ),
        'vogue-page-fimage-size-small' => __( 'Small Banner', 'vogue' ),
        'vogue-page-fimage-size-medium' => __( 'Medium Banner', 'vogue' ),
        'vogue-page-fimage-size-large' => __( 'Large Banner', 'vogue' ),
        'vogue-page-fimage-size-actual' => __( 'Use Proper Image', 'vogue' )
    );
    $options['vogue-page-fimage-size'] = array(
        'id' => 'vogue-page-fimage-size',
        'label'   => __( 'Page Banner Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-page-fimage-size-medium'
    );
    $options['vogue-page-fimage-fullwidth'] = array(
        'id' => 'vogue-page-fimage-fullwidth',
        'label'   => __( 'Full Width Banner', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    
    // WooCommerce style Layout
    if ( vogue_is_woocommerce_activated() ) :
        
        $section = 'vogue-woocommerce-layout-section';
        
        $sections[] = array(
            'id' => $section,
            'title' => __( 'WooCommerce', 'vogue' ),
            'priority' => '10',
            'panel' => $panel
        );
        
        $choices = array(
            'vogue-woocommerce-layout-standard' => __( 'Standard Layout', 'vogue' ),
            'vogue-woocommerce-layout-centered' => __( 'Big Blocks Layout', 'vogue' )
        );
        $options['vogue-woocommerce-layout'] = array(
            'id' => 'vogue-woocommerce-layout',
            'label'   => __( 'WooCommerce Layout', 'vogue' ),
            'section' => $section,
            'type'    => 'select',
            'choices' => $choices,
            'default' => 'vogue-woocommerce-layout-standard',
            'description' => __( '', 'vogue' )
        );
	    
        $options['vogue-woocommerce-shop-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-leftsidebar',
            'label'   => __( 'Set Shop sidebar to Left', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-archive-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-archive-leftsidebar',
            'label'   => __( 'Set Shop archive sidebar to Left', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-single-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-single-leftsidebar',
            'label'   => __( 'Set Shop single pages sidebar to left', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        
        $options['vogue-woocommerce-shop-fullwidth'] = array(
			'id' => 'vogue-woocommerce-shop-fullwidth',
			'label'   => __( 'Make Shop page full width', 'vogue' ),
			'section' => $section,
			'type'    => 'checkbox',
			'default' => 0,
		);
        $options['vogue-woocommerce-shop-archive-fullwidth'] = array(
            'id' => 'vogue-woocommerce-shop-archive-fullwidth',
            'label'   => __( 'Make Shop archive pages full width', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-single-fullwidth'] = array(
            'id' => 'vogue-woocommerce-shop-single-fullwidth',
            'label'   => __( 'Make Shop single pages full width', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        
    endif;
	
	
	// Header Layout Options
	$section = 'vogue-header-section';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Header Options', 'vogue' ),
		'priority' => '30',
		'description' => __( '', 'vogue' )
	);
	
	$options['vogue-header-remove-topbar'] = array(
		'id' => 'vogue-header-remove-topbar',
		'label'   => __( 'Remove the Top Bar', 'vogue' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 0,
	);
    
    $choices = array(
        'vogue-header-layout-one' => __( 'Header Centered One', 'vogue' ),
        'vogue-header-layout-two' => __( 'Header Centered Two', 'vogue' ),
        'vogue-header-layout-three' => __( 'Header Standard', 'vogue' ),
        'vogue-header-layout-four' => __( 'Header Standard Two', 'vogue' )
    );
    $options['vogue-header-layout'] = array(
        'id' => 'vogue-header-layout',
        'label'   => __( 'Header Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-header-layout-one'
    );
    
    $choices = array(
        'vogue-header-density-comfortable' => __( 'Comfortable', 'vogue' ),
        'vogue-header-density-compact' => __( 'Compact', 'vogue' )
    );
    $options['vogue-header-density'] = array(
        'id' => 'vogue-header-density',
        'label'   => __( 'Header density', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-header-density-comfortable'
    );
	
	$options['vogue-header-menu-text'] = array(
		'id' => 'vogue-header-menu-text',
		'label'   => __( 'Menu Button Text', 'vogue' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'menu',
		'description' => __( 'This is the text for the mobile menu button', 'vogue' )
	);
	
	$options['vogue-header-search'] = array(
        'id' => 'vogue-header-search',
        'label'   => __( 'Hide Search', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-social'] = array(
        'id' => 'vogue-header-hide-social',
        'label'   => __( 'Hide Social Links', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-add'] = array(
        'id' => 'vogue-header-hide-add',
        'label'   => __( 'Hide Address', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-no'] = array(
        'id' => 'vogue-header-hide-no',
        'label'   => __( 'Hide Phone Number', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    // WooCommerce Header Cart
    if ( vogue_is_woocommerce_activated() ) :
        
        $options['vogue-header-remove-cart'] = array(
            'id' => 'vogue-header-remove-cart',
            'label'   => __( 'Remove the WooCommerce Cart', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        
    endif;
    
    
    // Slider Settings
    $section = 'vogue-slider-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Slider Options', 'vogue' ),
        'priority' => '35'
    );
    
    $choices = array(
        'vogue-slider-default' => __( 'Default Slider', 'vogue' ),
        'vogue-meta-slider' => __( 'Meta Slider', 'vogue' ),
        'vogue-no-slider' => __( 'None', 'vogue' )
    );
    $options['vogue-slider-type'] = array(
        'id' => 'vogue-slider-type',
        'label'   => __( 'Choose a Slider', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-slider-default'
    );
    $options['vogue-slider-cats'] = array(
        'id' => 'vogue-slider-cats',
        'label'   => __( 'Slider Categories', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the ID\'s of the post categories you want to display in the slider. Eg: "13,17,19" (no spaces and only comma\'s)<br /><a href="https://kairaweb.com/documentation/setting-up-the-default-slider/" target="_blank"><b>Follow instructions here</b></a>', 'vogue' )
    );
    $options['vogue-meta-slider-shortcode'] = array(
        'id' => 'vogue-meta-slider-shortcode',
        'label'   => __( 'Slider Shortcode', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the shortcode give by the slider plugin', 'vogue' )
    );
    $choices = array(
        'vogue-slider-size-small' => __( 'Small Slider', 'vogue' ),
        'vogue-slider-size-medium' => __( 'Medium Slider', 'vogue' ),
        'vogue-slider-size-large' => __( 'Large Slider', 'vogue' )
    );
    $options['vogue-slider-size'] = array(
        'id' => 'vogue-slider-size',
        'label'   => __( 'Slider Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-slider-size-medium'
    );
    $choices = array(
        'crossfade' => __( 'Cross Fade', 'vogue' ),
        'cover-fade' => __( 'Cover Fade', 'vogue' ),
        'uncover-fade' => __( 'Uncover Fade', 'vogue' ),
        'cover' => __( 'Cover', 'vogue' ),
        'scroll' => __( 'Scroll', 'vogue' )
    );
    $options['vogue-slider-scroll-effect'] = array(
        'id' => 'vogue-slider-scroll-effect',
        'label'   => __( 'Scroll Effect', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'uncover-fade'
    );
    $options['vogue-slider-duration'] = array(
        'id' => 'vogue-slider-duration',
        'label'   => __( 'Scroll Duration', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'The amount of time the slider takes to scroll to the next slide. 1000 = 1 Second', 'vogue' ),
        'default' => 6500,
    );
    $options['vogue-slider-linkto-post'] = array(
        'id' => 'vogue-slider-linkto-post',
        'label'   => __( 'Link Slide to post', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-remove-title'] = array(
        'id' => 'vogue-slider-remove-title',
        'label'   => __( 'Remove Slider Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
	$options['vogue-slider-auto-scroll'] = array(
        'id' => 'vogue-slider-auto-scroll',
        'label'   => __( 'Stop Auto Scroll', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );

    
    // Header Image
    $section = 'header_image';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header Image', 'vogue' ),
        'priority' => '80'
    );
    $options['vogue-header-image-show-title'] = array(
        'id' => 'vogue-header-image-show-title',
        'label'   => __( 'Show Site Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box if you\'ve uploaded a header image and still want to show the site title next to the image', 'vogue' ),
        'default' => 0,
    );
    $options['vogue-header-image-show-tagline'] = array(
        'id' => 'vogue-header-image-show-tagline',
        'label'   => __( 'Show Site Tagline', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box if you\'ve uploaded a header image and still want to show the Tagline<br /><br />These only work when a header image is set', 'vogue' ),
        'default' => 0,
    );
    $options['vogue-header-image-logo-max-width'] = array(
        'id' => 'vogue-header-image-logo-max-width',
        'label'   => __( 'Set a max-width for the logo', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'This only applies if a logo image is uploaded', 'vogue' ),
        'default' => '',
    );
    
    
	// Colors
	$section = 'colors';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Colors', 'vogue' ),
		'priority' => '80'
	);
    
    $options['vogue-boxed-bg-color'] = array(
        'id' => 'vogue-boxed-bg-color',
        'label'   => __( 'Site Boxed Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $site_boxed_color,
    );
    
	$options['vogue-primary-color'] = array(
		'id' => 'vogue-primary-color',
		'label'   => __( 'Primary Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color,
	);

	$options['vogue-secondary-color'] = array(
		'id' => 'vogue-secondary-color',
		'label'   => __( 'Secondary Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
    
    $panel = 'vogue-panel-colors';
    
    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Layout Colors', 'vogue' ),
        'priority' => '80'
    );
    
    $section = 'vogue-panel-colors-section-header';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-header-bg-color'] = array(
        'id' => 'vogue-header-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-header-font-color'] = array(
        'id' => 'vogue-header-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    
    $options['vogue-topbar-bg-color'] = array(
        'id' => 'vogue-topbar-bg-color',
        'label'   => __( 'Top Bar Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-topbar-font-color'] = array(
        'id' => 'vogue-topbar-font-color',
        'label'   => __( 'Top Bar Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    
    $section = 'vogue-panel-colors-section-slider';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Default Slider', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-slider-block-bg-color'] = array(
        'id' => 'vogue-slider-block-bg-color',
        'label'   => __( 'Block Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#000000',
    );
    $options['vogue-slider-block-font-color'] = array(
        'id' => 'vogue-slider-block-font-color',
        'label'   => __( 'Block Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#FFFFFF',
    );
    $options['vogue-slider-block-opacity'] = array(
        'id' => 'vogue-slider-block-opacity',
        'label'   => __( 'Block Opacity', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 99,
            'step'  => 1,
        ),
        'default' => 60
    );
    
    $section = 'vogue-panel-colors-section-nav';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Navigation', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-nav-bg-color'] = array(
        'id' => 'vogue-nav-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-nav-font-color'] = array(
        'id' => 'vogue-nav-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-nav-font-hover-color'] = array(
        'id' => 'vogue-nav-font-hover-color',
        'label'   => __( 'Font Hover Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );
    
    $options['vogue-nav-drop-bg-color'] = array(
        'id' => 'vogue-nav-drop-bg-color',
        'label'   => __( 'Drop Down Bg Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-nav-drop-font-color'] = array(
        'id' => 'vogue-nav-drop-font-color',
        'label'   => __( 'DropDown Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    
    $section = 'vogue-panel-colors-section-nav-mobile';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Mobile Navigation', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $choices = array(
        'vogue-mobile-nav-skin-dark' => __( 'Dark Skin', 'vogue' ),
        'vogue-mobile-nav-skin-light' => __( 'Light Skin', 'vogue' ),
        'vogue-mobile-nav-skin-custom' => __( 'Custom Colors', 'vogue' )
    );
    $options['vogue-mobile-nav-skin'] = array(
        'id' => 'vogue-mobile-nav-skin',
        'label'   => __( 'Mobile Navigation Colors', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-mobile-nav-skin-dark'
    );
    $options['vogue-mobile-nav-bg-color'] = array(
        'id' => 'vogue-mobile-nav-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#000000',
    );
    $options['vogue-mobile-nav-font-color'] = array(
        'id' => 'vogue-mobile-nav-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#C5C5C5',
    );
    $options['vogue-mobile-nav-cart-font-color'] = array(
        'id' => 'vogue-mobile-nav-cart-font-color',
        'label'   => __( 'Cart Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#FFFFFF',
    );
    
    $section = 'vogue-panel-colors-section-footer';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-footer-bg-color'] = array(
        'id' => 'vogue-footer-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-footer-heading-font-color'] = array(
        'id' => 'vogue-footer-heading-font-color',
        'label'   => __( 'Heading Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-footer-font-color'] = array(
        'id' => 'vogue-footer-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    
    $options['vogue-footer-bottombar-bg-color'] = array(
        'id' => 'vogue-footer-bottombar-bg-color',
        'label'   => __( 'Bottom Bar Bg Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-footer-bottombar-font-color'] = array(
        'id' => 'vogue-footer-bottombar-font-color',
        'label'   => __( 'Bottom Bar Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    

	// Font Options
	$section = 'vogue-typography-section';
	$font_choices = customizer_library_get_font_choices();

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Font Options', 'vogue' ),
		'priority' => '80'
	);
    
    $options['vogue-title-font'] = array(
        'id' => 'vogue-title-font',
        'label'   => __( 'Site Title Font', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Lato'
    );
    $options['vogue-title-font-size'] = array(
        'id' => 'vogue-title-font-size',
        'label'   => __( 'Site Title Size', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 70,
    );
    $options['vogue-tagline-font-size'] = array(
        'id' => 'vogue-tagline-font-size',
        'label'   => __( 'Site Tagline Size', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 12,
    );
    $options['vogue-title-bottom-margin'] = array(
        'id' => 'vogue-title-bottom-margin',
        'label'   => __( 'Site Title Bottom Margin', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'This will set the space between the site title and the site tagline', 'vogue' ),
        'default' => 0,
    );
    
	$options['vogue-body-font'] = array(
		'id' => 'vogue-body-font',
		'label'   => __( 'Body Font', 'vogue' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $font_choices,
		'default' => 'Open Sans'
	);
	$options['vogue-body-font-color'] = array(
		'id' => 'vogue-body-font-color',
		'label'   => __( 'Body Font Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $body_font_color,
	);

	$options['vogue-heading-font'] = array(
		'id' => 'vogue-heading-font',
		'label'   => __( 'Heading Font', 'vogue' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $font_choices,
		'default' => 'Lato'
	);
	$options['vogue-heading-font-color'] = array(
		'id' => 'vogue-heading-font-color',
		'label'   => __( 'Heading Font Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $heading_font_color,
	);
    $options['vogue-note-fonts'] = array(
        'id' => 'vogue-note-fonts',
        'section' => $section,
        'type'    => 'note',
        'description' => __( 'We have documentation on <a href="https://kairaweb.com/documentation/change-font-sizes-custom-css/" target="_blank">changing theme font sizes</a>', 'vogue' ),
    );
	
    
    $panel = 'vogue-panel-blog';
    
    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Blog Options', 'vogue' ),
        'priority' => '50'
    );
    
    $section = 'vogue-blog-section';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Blog', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['vogue-blog-title'] = array(
        'id' => 'vogue-blog-title',
        'label'   => __( 'Blog Page Title', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => 'Blog'
    );
    $choices = array(
        'blog-left-layout' => __( 'Left Layout', 'vogue' ),
        'blog-right-layout' => __( 'Right Layout', 'vogue' ),
        'blog-top-layout' => __( 'Top Layout', 'vogue' ),
        'blog-alt-layout' => __( 'Alternate Layout', 'vogue' ),
        'blog-grid-layout' => __( 'Masonry Grid Layout', 'vogue' )
    );
    $options['vogue-blog-layout'] = array(
        'id' => 'vogue-blog-layout',
        'label'   => __( 'Blog Posts Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'description' => __( 'This uses the "Large Size" image cut', 'vogue' ),
        'default' => 'blog-left-layout'
    );
    $choices = array(
        'blog-grid-column-two' => __( '2', 'vogue' ),
        'blog-grid-column-three' => __( '3', 'vogue' ),
        'blog-grid-column-four' => __( '4', 'vogue' ),
        'blog-grid-column-five' => __( '5', 'vogue' )
    );
    $options['vogue-blog-columns'] = array(
        'id' => 'vogue-blog-columns',
        'label'   => __( 'Grid Columns', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-grid-column-three'
    );
    $choices = array(
        'blog-style-plain' => __( 'Plain Styling', 'vogue' ),
        'blog-style-block' => __( 'Block Styling', 'vogue' )
    );
    $options['vogue-blog-styling'] = array(
        'id' => 'vogue-blog-styling',
        'label'   => __( 'Blog Styling', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-style-plain'
    );
    $choices = array(
        'blog-img-shape-img' => __( 'Image Shape Blocks', 'vogue' ),
        'blog-img-shape-square' => __( 'Square Blocks', 'vogue' )
    );
    $options['vogue-blog-img-shape'] = array(
        'id' => 'vogue-blog-img-shape',
        'label'   => __( 'Blog Image Shape', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-img-shape-img'
    );
    $options['vogue-blog-cats'] = array(
        'id' => 'vogue-blog-cats',
        'label'   => __( 'Exclude Blog Categories', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the ID\'s of the post categories you\'d like to EXCLUDE from the Blog, enter only the ID\'s with a minus sign (-) before them, separated by a comma (,)<br />Eg: "-13, -17, -19"<br />If you enter the ID\'s without the minus then it\'ll show ONLY posts in those categories.', 'vogue' )
    );
    $choices = array(
        'blog-display-full-text' => __( 'Full Text', 'vogue' ),
        'blog-display-summary' => __( 'Summary', 'vogue' )
    );
    $options['vogue-article-content-display'] = array(
        'id' => 'vogue-article-content-display',
        'label'   => __( 'For each article display:', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-display-full-text'
    );
    $options['vogue-article-content-word-count'] = array(
        'id' => 'vogue-article-content-word-count',
        'label'   => __( 'Amount of words displayed', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 40
    );
    $options['vogue-article-content-readmore'] = array(
        'id' => 'vogue-article-content-readmore',
        'label'   => __( 'Read More Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => '...Read More'
    );
    $options['vogue-blog-remove-meta'] = array(
        'id' => 'vogue-blog-remove-meta',
        'label'   => __( 'Remove blog meta', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-remove-excerpt'] = array(
        'id' => 'vogue-blog-remove-excerpt',
        'label'   => __( 'Remove Excerpt/Content', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-remove-tags-cats'] = array(
        'id' => 'vogue-blog-remove-tags-cats',
        'label'   => __( 'Remove the tags and categories', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    $options['vogue-blog-leftsidebar'] = array(
        'id' => 'vogue-blog-leftsidebar',
        'label'   => __( 'Blog Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-cat-leftsidebar'] = array(
        'id' => 'vogue-blog-cat-leftsidebar',
        'label'   => __( 'Archives/Categories Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-search-leftsidebar'] = array(
        'id' => 'vogue-blog-search-leftsidebar',
        'label'   => __( 'Search Results Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-full-width'] = array(
        'id' => 'vogue-blog-full-width',
        'label'   => __( 'Make Blog Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-cat-full-width'] = array(
        'id' => 'vogue-blog-cat-full-width',
        'label'   => __( 'Make Archives/Categories full width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-search-full-width'] = array(
        'id' => 'vogue-blog-search-full-width',
        'label'   => __( 'Make Search Results Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    $section = 'vogue-blog-single-section';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Single Posts', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );
    
    $options['vogue-blog-single-leftsidebar'] = array(
        'id' => 'vogue-blog-single-leftsidebar',
        'label'   => __( 'Post Single Pages Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-full-width'] = array(
        'id' => 'vogue-blog-single-full-width',
        'label'   => __( 'Make Post Single Pages Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $choices = array(
        'vogue-single-page-fimage-layout-none' => __( 'None', 'vogue' ),
        'vogue-single-page-fimage-layout-standard' => __( 'Standard', 'vogue' ),
        'vogue-single-page-fimage-layout-banner' => __( 'Page Banner', 'vogue' )
    );
    $options['vogue-single-page-fimage-layout'] = array(
        'id' => 'vogue-single-page-fimage-layout',
        'label'   => __( 'Featured Image Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-single-page-fimage-layout-none'
    );
    $choices = array(
        'vogue-single-page-fimage-size-extra-small' => __( 'Extra Small Banner', 'vogue' ),
        'vogue-single-page-fimage-size-small' => __( 'Small Banner', 'vogue' ),
        'vogue-single-page-fimage-size-medium' => __( 'Medium Banner', 'vogue' ),
        'vogue-single-page-fimage-size-large' => __( 'Large Banner', 'vogue' ),
        'vogue-single-page-fimage-size-actual' => __( 'Use Proper Image', 'vogue' )
    );
    $options['vogue-single-page-fimage-size'] = array(
        'id' => 'vogue-single-page-fimage-size',
        'label'   => __( 'Page Banner Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-single-page-fimage-size-medium'
    );
    $options['vogue-single-page-fimage-fullwidth'] = array(
        'id' => 'vogue-single-page-fimage-fullwidth',
        'label'   => __( 'Full Width Banner', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-title'] = array(
        'id' => 'vogue-blog-single-remove-title',
        'label'   => __( 'Remove Post Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-meta'] = array(
        'id' => 'vogue-blog-single-remove-meta',
        'label'   => __( 'Remove Post Meta', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-tags-cats'] = array(
        'id' => 'vogue-blog-single-remove-tags-cats',
        'label'   => __( 'Remove the tags and categories', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
	
	
	// Footer Settings
    $section = 'vogue-footer-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer Layout Options', 'vogue' ),
        'priority' => '85'
    );
    
    $choices = array(
        'vogue-footer-layout-standard' => __( 'Standard Layout', 'vogue' ),
        'vogue-footer-layout-centered' => __( 'Centered Layout', 'vogue' ),
        'vogue-footer-layout-social' => __( 'Social Layout', 'vogue' ),
        'vogue-footer-layout-custom' => __( 'Custom Layout', 'vogue' ),
        'vogue-footer-layout-none' => __( 'None', 'vogue' )
    );
    $options['vogue-footer-layout'] = array(
        'id' => 'vogue-footer-layout',
        'label'   => __( 'Footer Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-footer-layout-social'
    );
    
    $options['vogue-footer-bottombar'] = array(
        'id' => 'vogue-footer-bottombar',
        'label'   => __( 'Remove the Bottom Bar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-footer-hide-social'] = array(
        'id' => 'vogue-footer-hide-social',
        'label'   => __( 'Hide Social Links', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    
    
    $choices = array(
        'vogue-footer-custom-cols-1' => __( '1 Column', 'vogue' ),
        'vogue-footer-custom-cols-2' => __( '2 Columns', 'vogue' ),
        'vogue-footer-custom-cols-3' => __( '3 Columns', 'vogue' ),
        'vogue-footer-custom-cols-4' => __( '4 Columns', 'vogue' ),
        'vogue-footer-custom-cols-5' => __( '5 Columns', 'vogue' )
    );
    $options['vogue-footer-custom-cols'] = array(
        'id' => 'vogue-footer-custom-cols',
        'label'   => __( 'Columns', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-footer-custom-cols-3'
    );
    
    $options['vogue-footer-customize'] = array(
        'id' => 'vogue-footer-customize',
        'label'   => __( 'Custom Widths', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box to manually adjust the columns widths by percentage ( % )', 'vogue' ),
        'default' => 0,
    );
    
    $options['vogue-footer-customize-col-1'] = array(
        'id' => 'vogue-footer-customize-col-1',
        'label'   => __( 'Column 1 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( '', 'vogue' ),
        'default' => '',
    );
    $options['vogue-footer-customize-col-2'] = array(
        'id' => 'vogue-footer-customize-col-2',
        'label'   => __( 'Column 2 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( '', 'vogue' ),
        'default' => '',
    );
    $options['vogue-footer-customize-col-3'] = array(
        'id' => 'vogue-footer-customize-col-3',
        'label'   => __( 'Column 3 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( '', 'vogue' ),
        'default' => '',
    );
    $options['vogue-footer-customize-col-4'] = array(
        'id' => 'vogue-footer-customize-col-4',
        'label'   => __( 'Column 4 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( '', 'vogue' ),
        'default' => '',
    );
    $options['vogue-footer-customize-col-5'] = array(
        'id' => 'vogue-footer-customize-col-5',
        'label'   => __( 'Column 5 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( '', 'vogue' ),
        'default' => '',
    );
    
    
	// Site Text Settings
    $section = 'vogue-website-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Website Text', 'vogue' ),
        'priority' => '50'
    );
    
    $options['vogue-website-site-add'] = array(
        'id' => 'vogue-website-site-add',
        'label'   => __( 'Header Address', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Cape Town, South Africa', 'vogue' ),
        'description' => __( 'This is the address in the header top bar and the social footer', 'vogue' )
    );
    $options['vogue-website-head-no'] = array(
        'id' => 'vogue-website-head-no',
        'label'   => __( 'Header Phone Number', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Call Us: +2782 444 YEAH', 'vogue' ),
        'description' => __( 'This is the phone number in the header top bar', 'vogue' )
    );
    
    $options['vogue-website-txt-copy'] = array(
        'id' => 'vogue-website-txt-copy',
        'label'   => __( 'Site Copy Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'vogue theme, by <a href="https://kairaweb.com/">Kaira</a>', 'vogue'),
        'description' => __( 'Enter the text in the bottom bar of the footer', 'vogue' )
    );
    $options['vogue-website-error-head'] = array(
        'id' => 'vogue-website-error-head',
        'label'   => __( '404 Error Page Heading', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Oops! <span>404</span>', 'vogue'),
        'description' => __( 'Enter the heading for the 404 Error page', 'vogue' )
    );
    $options['vogue-website-error-msg'] = array(
        'id' => 'vogue-website-error-msg',
        'label'   => __( 'Error 404 Message', 'vogue' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'It looks like that page does not exist. <br />Return home or try a search', 'vogue'),
        'description' => __( 'Enter the default text on the 404 error page (Page not found)', 'vogue' )
    );
    $options['vogue-website-nosearch-msg'] = array(
        'id' => 'vogue-website-nosearch-msg',
        'label'   => __( 'No Search Results', 'vogue' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vogue'),
        'description' => __( 'Enter the default text for when no search results are found', 'vogue' )
    );
	
	
	// Social Settings
    $section = 'vogue-social-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Social Links', 'vogue' ),
        'priority' => '80'
    );
    
    $options['vogue-social-email'] = array(
        'id' => 'vogue-social-email',
        'label'   => __( 'Email Address', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-skype'] = array(
        'id' => 'vogue-social-skype',
        'label'   => __( 'Skype Name', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-facebook'] = array(
        'id' => 'vogue-social-facebook',
        'label'   => __( 'Facebook', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-twitter'] = array(
        'id' => 'vogue-social-twitter',
        'label'   => __( 'Twitter', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-google-plus'] = array(
        'id' => 'vogue-social-google-plus',
        'label'   => __( 'Google Plus', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-snapchat'] = array(
        'id' => 'vogue-social-snapchat',
        'label'   => __( 'SnapChat', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-youtube'] = array(
        'id' => 'vogue-social-youtube',
        'label'   => __( 'YouTube', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-instagram'] = array(
        'id' => 'vogue-social-instagram',
        'label'   => __( 'Instagram', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-pinterest'] = array(
        'id' => 'vogue-social-pinterest',
        'label'   => __( 'Pinterest', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-medium'] = array(
        'id' => 'vogue-social-medium',
        'label'   => __( 'Medium', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-behance'] = array(
        'id' => 'vogue-social-behance',
        'label'   => __( 'Behance', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-product-hunt'] = array(
        'id' => 'vogue-social-product-hunt',
        'label'   => __( 'Product Hunt', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-slack'] = array(
        'id' => 'vogue-social-slack',
        'label'   => __( 'Slack', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-linkedin'] = array(
        'id' => 'vogue-social-linkedin',
        'label'   => __( 'LinkedIn', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-tumblr'] = array(
        'id' => 'vogue-social-tumblr',
        'label'   => __( 'Tumblr', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-flickr'] = array(
        'id' => 'vogue-social-flickr',
        'label'   => __( 'Flickr', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-houzz'] = array(
        'id' => 'vogue-social-houzz',
        'label'   => __( 'Houzz', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-vk'] = array(
        'id' => 'vogue-social-vk',
        'label'   => __( 'VK', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-tripadvisor'] = array(
        'id' => 'vogue-social-tripadvisor',
        'label'   => __( 'TripAdvisor', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    
    
    // Site Layout Options
    $section = 'vogue-plugin-support-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Plugin Support', 'vogue' ),
        'priority' => '120',
        'description' => __( 'Add Vogue custom styling to selected plugins.<br /><br />Lots more coming soon...', 'vogue' )
    );
    
    $options['vogue-plugin-styling-buddypress'] = array(
        'id' => 'vogue-plugin-styling-buddypress',
        'label'   => __( 'BuddyPress', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
	

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_vogue_options' );
